@@ -585,7 +585,7 @@ class MMapIndexedDatasetBuilder(object):
             index.write(self._sizes, self._doc_idx)
 
 
-def get_indexed_dataset(data_prefix, data_impl, skip_warmup, align_postfix=None):
+def get_indexed_dataset(data_prefix, data_impl, skip_warmup):
 
     logger.info("building dataset index ...")
 
@@ -600,14 +600,4 @@ def get_indexed_dataset(data_prefix, data_impl, skip_warmup, align_postfix=None)
     logger.info("number of documents: {}".format(indexed_dataset.doc_idx.shape[0] - 1))
     logger.info("number of sentences: {}".format(indexed_dataset.sizes.shape[0]))
 
-    if align_postfix is not None:
-        align_data_prefix = data_prefix + "-" + align_postfix
-        start_time = time.time()
-        align_indexed_dataset = make_dataset(align_data_prefix, data_impl, skip_warmup)
-        assert indexed_dataset.sizes.shape[0] == indexed_dataset.doc_idx[-1]
-        logger.info(
-            "inished creating indexed dataset in {:4f} " "seconds".format(time.time() - start_time)
-        )
-        indexed_dataset = (indexed_dataset, align_indexed_dataset)
-
     return indexed_dataset
