@@ -21,7 +21,6 @@ import time
 import numpy as np
 import oneflow as flow
 
-from libai.data.data_utils import helpers
 from libai.utils import distributed as dist
 
 logger = logging.getLogger(__name__)
@@ -51,8 +50,16 @@ def get_samples_mapping(data_prefix, indexed_dataset, max_seq_length, short_seq_
         verbose = flow.env.get_rank() == 0
         start_time = time.time()
         logger.info("building samples index mapping for {} ...".format(data_prefix))
+
+        from libai.data.data_utils import helpers
+
         samples_mapping = helpers.build_mapping(
-            documents, sizes, max_seq_length, short_seq_prob, verbose, 2 if binary_head else 1,
+            documents,
+            sizes,
+            max_seq_length,
+            short_seq_prob,
+            verbose,
+            2 if binary_head else 1,
         )
         logger.info("done building samples index maping")
         np.save(indexmap_filename, samples_mapping, allow_pickle=True)
@@ -96,12 +103,7 @@ class SentenceIndexedDataset(flow.utils.data.Dataset):
         self.max_seq_length = max_seq_length
         self.short_seq_prob = short_seq_prob
         self.binary_head = binary_head
-        if isinstance(indexed_dataset, (list, tuple)):
-            self.indexed_dataset = indexed_dataset[0]
-            self.align_indexed_dataset = indexed_dataset[1] if len(indexed_dataset) > 1 else None
-        else:
-            self.indexed_dataset = indexed_dataset
-            self.align_indexed_dataset = None
+        self.indexed_dataset = indexed_dataset
 
         self.samples_mapping = get_samples_mapping(
             data_prefix,
@@ -117,9 +119,6 @@ class SentenceIndexedDataset(flow.utils.data.Dataset):
     def __getitem__(self, idx):
         start_idx, end_idx, seq_length = self.samples_mapping[idx]
         sample = [self.indexed_dataset[i] for i in range(start_idx, end_idx)]
-        if self.align_indexed_dataset is not None:
-            align_sample = [self.align_indexed_dataset[i] for i in range(start_idx, end_idx)]
-            sample = (sample, align_sample)
         assert seq_length <= self.max_seq_length
         return sample
 
@@ -133,8 +132,6 @@ class SentenceIndexedDataset(flow.utils.data.Dataset):
             start_idx, end_idx, _ = self.samples_mapping[idx]
             new_indices.extend([i for i in range(start_idx, end_idx)])
         self.indexed_dataset.prefetch(new_indices)
-        if self.align_indexed_dataset is not None:
-            self.align_indexed_dataset(new_indices)
 
 
 def build_index_mappings(data_prefix, indexed_dataset, max_seq_length):
@@ -148,7 +145,7 @@ def build_index_mappings(data_prefix, indexed_dataset, max_seq_length):
 
     documents = indexed_dataset.doc_idx.astype(np.int64)
     sizes = indexed_dataset.sizes.astype(np.int64)
-    num_tokens = np.sum(sizes)
+    num_tokens = np.sum(sizes[documents[:-1]])
 
     # Build the indexed mapping if not exist.
     if flow.env.get_rank() == 0 and not os.path.isfile(indexmap_filename):
@@ -156,6 +153,9 @@ def build_index_mappings(data_prefix, indexed_dataset, max_seq_length):
 
         # sample-idx.
         start_time = time.time()
+
+        from libai.data.data_utils import helpers
+
         sample_idx = helpers.build_sample_idx(documents, sizes, max_seq_length, num_tokens)
         np.save(indexmap_filename, sample_idx, allow_pickle=True)
         logger.info(
@@ -187,12 +187,8 @@ class BlockIndexedDataset(flow.utils.data.Dataset):
 
     def __init__(self, data_prefix, indexed_dataset, max_seq_length=512):
         self.max_seq_length = max_seq_length
-        if isinstance(indexed_dataset, (list, tuple)):
-            self.indexed_dataset = indexed_dataset[0]
-            self.align_indexed_dataset = indexed_dataset[1] if len(indexed_dataset) > 1 else None
-        else:
-            self.indexed_dataset = indexed_dataset
-            self.align_indexed_dataset = None
+        self.indexed_dataset = indexed_dataset
+        self.doc_idx = indexed_dataset.doc_idx
 
         self.sample_idx = build_index_mappings(
             data_prefix, self.indexed_dataset, self.max_seq_length
@@ -208,31 +204,19 @@ class BlockIndexedDataset(flow.utils.data.Dataset):
         offset_l = self.sample_idx[idx + 1][1]
         if doc_index_f == doc_index_l:
             sample = self.indexed_dataset.get(
-                doc_index_f, offset=offset_f, length=offset_l - offset_f + 1
+                self.doc_idx[doc_index_f], offset=offset_f, length=offset_l - offset_f + 1
             )
-            if self.align_indexed_dataset is not None:
-                align_sample = self.align_indexed_dataset.get(
-                    doc_index_f, offset=offset_f, length=offset_l - offset_f + 1
-                )
-                sample = (sample, align_sample)
         else:
             # Otherwise, get the rest of the initial document.
-            sample_list = [self.indexed_dataset.get(doc_index_f, offset=offset_f)]
+            sample_list = [self.indexed_dataset.get(self.doc_idx[doc_index_f], offset=offset_f)]
             # Loop over all in between documents and add the entire document.
             for i in range(doc_index_f + 1, doc_index_l):
-                sample_list.append(self.indexed_dataset.get(i))
+                sample_list.append(self.indexed_dataset.get(self.doc_idx[i]))
             # And finally add the relevant portion of last document.
-            sample_list.append(self.indexed_dataset.get(doc_index_l, length=offset_l + 1))
+            sample_list.append(
+                self.indexed_dataset.get(self.doc_idx[doc_index_l], length=offset_l + 1)
+            )
             sample = np.concatenate(sample_list)
-            if self.align_indexed_dataset is not None:
-                align_sample_list = [self.align_indexed_dataset.get(doc_index_f, offset=offset_f)]
-                for i in range(doc_index_f + 1, doc_index_l):
-                    align_sample_list.append(self.align_indexed_dataset.get(i))
-                align_sample_list.append(
-                    self.align_indexed_dataset.get(doc_index_l, length=offset_l + 1)
-                )
-                align_sample = np.concatenate(align_sample_list)
-                sample = (sample, align_sample)
 
         return sample
 
