@@ -26,10 +26,34 @@ from libai.data.structures import DistTensorData, Instance
 MaskedLmInstance = collections.namedtuple("MaskedLmInstance", ["index", "label"])
 
 
+def is_start_piece(piece):
+    """Check if the current word piece is the starting piece (BERT)."""
+    # When a word has been split into
+    # WordPieces, the first token does not have any marker and any subsequence
+    # tokens are prefixed with ##. So whenever we see the ## token, we
+    # append it to the previous set of word indexes.
+    return not piece.startswith("##")
+
+
 class BertDataset(flow.utils.data.Dataset):
-    """
-    Dataset containing sentence pairs for BERT training.
+    """Dataset containing sentence pairs for BERT training.
     Each index corresponds to a randomly generated sentence pair.
+
+    Args:
+        tokenizer: Tokenizer to use.
+        data_prefix: Path to the training dataset.
+        indexed_dataset: Indexed dataset to use.
+        max_seq_length: Maximum length of the sequence. All values are padded to
+            this length. Defaults to 512.
+        mask_lm_prob: Probability to mask tokens. Defaults to 0.15.
+        short_seq_prob: Probability of producing a short sequence. Defaults to 0.0.
+        max_preds_per_seq: Maximum number of mask tokens in each sentence. Defaults to None.
+        seed: Seed for random number generator for reproducibility. Defaults to 1234.
+        binary_head: Specifies whether the underlying dataset
+            generates a pair of blocks along with a sentence_target or not.
+            Setting it to True assumes that the underlying dataset generates a
+            label for the pair of sentences which is surfaced as
+            sentence_target. Defaults to True.
     """
 
     def __init__(
@@ -53,10 +77,6 @@ class BertDataset(flow.utils.data.Dataset):
             max_preds_per_seq = math.ceil(max_seq_length * mask_lm_prob / 10) * 10
         self.max_preds_per_seq = max_preds_per_seq
 
-        self.has_align_dataset = (
-            isinstance(indexed_dataset, (list, tuple)) and len(indexed_dataset) > 1
-        )
-
         self.dataset = SentenceIndexedDataset(
             data_prefix,
             indexed_dataset,
@@ -78,47 +98,38 @@ class BertDataset(flow.utils.data.Dataset):
     def __getitem__(self, idx):
         # Note that this rng state should be numpy and not python since
         # python randint is inclusive whereas the numpy one is exclusive.
-        # We % 2 ** 32 since numpy requres the seed to be between 0 and 2 ** 32 - 1
-        np_rng = np.random.RandomState(seed=((self.seed + idx) % 2 ** 32))
+        np_rng = np.random.RandomState(seed=(self.seed + idx))
 
         sents = self.dataset[idx]
-        align_labels = None
-        if self.has_align_dataset:
-            sents, align_labels = sents
 
         if self.binary_head:
-            tokens_a, tokens_b, is_next_random = self.create_random_sentence_pair(
-                sents, np_rng, align_labels=align_labels
-            )
+            tokens_a, tokens_b, is_next_random = self.create_random_sentence_pair(sents, np_rng)
         else:
             tokens_a = []
             for j in range(len(sents)):
                 tokens_a.extend(sents[j])
             tokens_b = []
             is_next_random = False
-            if align_labels is not None:
-                align_labels_a = [label for labels in align_labels for label in labels]
-                align_labels_b = []
-                tokens_a = (tokens_a, align_labels_a)
-                tokens_b = (tokens_b, align_labels_b)
 
         tokens_a, tokens_b = self.truncate_seq_pair(
             tokens_a, tokens_b, self.max_seq_length - 3, np_rng
         )
 
-        tokens, token_types, align_labels = self.create_tokens_and_token_types(tokens_a, tokens_b)
+        tokens, token_types = self.create_tokens_and_token_types(tokens_a, tokens_b)
 
-        tokens, masked_positions, masked_labels = self.create_masked_lm_predictions(
-            tokens, np_rng, token_boundary=align_labels
-        )
+        tokens, masked_positions, masked_labels = self.create_masked_lm_predictions(tokens, np_rng)
 
-        (tokens, token_types, labels, padding_mask, loss_mask,) = self.pad_and_convert_to_tensor(
-            tokens, token_types, masked_positions, masked_labels
-        )
+        (
+            tokens,
+            token_types,
+            labels,
+            padding_mask,
+            loss_mask,
+        ) = self.pad_and_convert_to_tensor(tokens, token_types, masked_positions, masked_labels)
 
         sample = Instance(
-            tokens=DistTensorData(tokens),
-            padding_mask=DistTensorData(padding_mask),
+            input_ids=DistTensorData(tokens),
+            attention_mask=DistTensorData(padding_mask),
             tokentype_ids=DistTensorData(token_types),
             ns_labels=DistTensorData(
                 flow.tensor(int(is_next_random), dtype=flow.long), placement_idx=-1
@@ -128,7 +139,7 @@ class BertDataset(flow.utils.data.Dataset):
         )
         return sample
 
-    def create_random_sentence_pair(self, sample, np_rng, align_labels=None):
+    def create_random_sentence_pair(self, sample, np_rng):
         num_sentences = len(sample)
         assert num_sentences > 1, "make sure each sample has at least two sentences."
 
@@ -144,17 +155,6 @@ class BertDataset(flow.utils.data.Dataset):
         for j in range(a_end, num_sentences):
             tokens_b.extend(sample[j])
 
-        if align_labels is not None:
-            align_labels_a = []
-            align_labels_b = []
-            for j in range(a_end):
-                align_labels_a.extend(align_labels[j])
-            for j in range(a_end, num_sentences):
-                align_labels_b.extend(align_labels[j])
-
-            tokens_a = (tokens_a, align_labels_a)
-            tokens_b = (tokens_b, align_labels_b)
-
         is_next_random = False
         if np_rng.random() < 0.5:
             is_next_random = True
@@ -164,11 +164,6 @@ class BertDataset(flow.utils.data.Dataset):
 
     def truncate_seq_pair(self, tokens_a, tokens_b, max_num_tokens, np_rng):
         """truncate sequence pair to a maximum sequence length"""
-        if self.has_align_dataset:
-            tokens_a, align_labels_a = tokens_a
-            tokens_b, align_labels_b = tokens_b
-        else:
-            align_labels_a, align_labels_b = [], []
 
         len_a, len_b = len(tokens_a), len(tokens_b)
         while True:
@@ -177,48 +172,27 @@ class BertDataset(flow.utils.data.Dataset):
                 break
             if len_a > len_b:
                 trunc_tokens = tokens_a
-                trunc_labels = align_labels_a
                 len_a -= 1
             else:
                 trunc_tokens = tokens_b
-                trunc_labels = align_labels_b
                 len_b -= 1
 
             if np_rng.random() < 0.5:
                 trunc_tokens.pop(0)  # remove the first element
-                if len(trunc_labels) > 0:
-                    trunc_labels.pop(0)
             else:
                 trunc_tokens.pop()  # remove the last element
-                if len(trunc_labels) > 0:
-                    trunc_labels.pop()
-
-        if self.has_align_dataset:
-            tokens_a = (tokens_a, align_labels_a)
-            tokens_b = (tokens_b, align_labels_b)
 
         return tokens_a, tokens_b
 
     def create_tokens_and_token_types(self, tokens_a, tokens_b):
         """merge segments A and B, add [CLS] and [SEP] and build token types."""
-        if self.has_align_dataset:
-            tokens_a, align_labels_a = tokens_a
-            tokens_b, align_labels_b = tokens_b
-
         tokens = [self.cls_id] + tokens_a + [self.sep_id]
         token_types = [0] * (len(tokens_a) + 2)
         if len(tokens_b) > 0:
             tokens = tokens + tokens_b + [self.sep_id]
             token_types = token_types + [1] * (len(tokens_b) + 1)
 
-        if self.has_align_dataset:
-            align_labels = [1] + align_labels_a + [1]
-            if len(align_labels_b) > 0:
-                align_labels = align_labels + align_labels_b + [1]
-        else:
-            align_labels = None
-
-        return tokens, token_types, align_labels
+        return tokens, token_types
 
     def mask_token(self, idx, tokens, np_rng):
         """
@@ -243,18 +217,41 @@ class BertDataset(flow.utils.data.Dataset):
         tokens,
         np_rng,
         max_ngrams=3,
-        do_whole_word_mask=False,
-        token_boundary=None,
+        do_whole_word_mask=True,
         favor_longer_ngram=False,
         geometric_dist=False,
     ):
         """Creates the predictions for the masked LM objective.
         Note: Tokens here are vocab ids and not text tokens."""
 
-        if do_whole_word_mask:
-            assert (
-                token_boundary is not None
-            ), "token_boundary must be privided when do_whole_word_mask is True."
+        cand_indexes = []
+        token_boundary = [0] * len(tokens)
+        new_tokens = []
+
+        for (i, token) in enumerate(tokens):
+            new_tokens.append(token % len(self.tokenizer))
+
+            if token == self.cls_id or token == self.sep_id:
+                token_boundary[i] = 1
+                continue
+            # Whole Word Masking means that if we mask all of the wordpieces
+            # corresponding to an original word.
+            #
+            # Note that Whole Word Masking does *not* change the training code
+            # at all -- we still predict each WordPiece independently, softmaxed
+            # over the entire vocabulary.
+            if (
+                do_whole_word_mask
+                and len(cand_indexes) >= 1
+                and not is_start_piece(self.tokenizer._convert_id_to_token(token))
+            ):
+                cand_indexes[-1].append(i)
+            else:
+                cand_indexes.append([i])
+                if is_start_piece(self.tokenizer._convert_id_to_token(token)):
+                    token_boundary[i] = 1
+
+        tokens = new_tokens
 
         masked_positions = []
         masked_labels = []
@@ -382,6 +379,7 @@ class BertDataset(flow.utils.data.Dataset):
             assert idx < num_tokens
             labels[idx] = label
             loss_mask[idx] = 1
+
         labels = flow.tensor(labels, dtype=flow.long)
         loss_mask = flow.tensor(loss_mask, dtype=flow.long)
 
