@@ -17,6 +17,7 @@ import datetime
 import logging
 import time
 from collections import OrderedDict, abc
+from contextlib import ExitStack, contextmanager
 from typing import Callable, List, Union
 
 import oneflow as flow
@@ -45,26 +46,31 @@ class DatasetEvaluator:
     def process(self, inputs, outputs):
         """
         Process the pair of inputs and outputs.
-        If they contain batches, the pairs can be consumed one-by-one using `zip`:
+
         .. code-block:: python
-            for input_, output in zip(inputs, outputs):
-                # do evaluation on single input/output pair
-                ...
+
+            pred_logits = outputs["prediction_scores"]
+            labels = inputs["labels"]
+            # do evaluation on pred_logits/labels pair
+            ...
+
         Args:
-            inputs (list): the inputs that's used to call the model.
-            outputs (list): the return value of `model(inputs)`
+            inputs (dict): the inputs that's used to call the model.
+            outputs (dict): the return dict of `model(**inputs)`
         """
 
     def evaluate(self):
         """
         Evaluate/summarize the performance, after processing all input/output pairs.
+
         Returns:
             dict:
                 A new evaluator class can return a dict of arbitrary format
                 as long as the user can process the results.
                 In our train_net.py, we expect the following format:
-                * key: the name of the task (e.g., bbox)
-                * value: a dict of {metric name: score}, e.g.: {"AP50": 80}
+
+                * key: the name of the task (e.g., Classification)
+                * value: a dict of {metric name: score}, e.g.: {"Acc@1": 75.0}
         """
 
 
@@ -108,6 +114,7 @@ def inference_on_dataset(
     model,
     data_loader,
     batch_size,
+    eval_iter,
     get_batch: Callable,
     evaluator: Union[DatasetEvaluator, List[DatasetEvaluator], None],
 ):
@@ -115,6 +122,7 @@ def inference_on_dataset(
     Run model on the data_loader and evaluate the metrics with evaluator.
     Also benchmark the inference speed of `model.__call__` accurately.
     The model will be used in eval mode.
+
     Args:
         model (callable): a callable which takes an object from
             `data_loader` and returns some outputs.
@@ -124,17 +132,18 @@ def inference_on_dataset(
         batch_size: batch size for inference
         data_loader: an iterable object with a length.
             The elements it generates will be the inputs to the model.
+        eval_iter: running steps for evaluation
         get_batch: a Callable function for getting data from dataloader
         evaluator: the evaluator(s) to run. Use `None` if you only want to benchmark,
             but don't want to do any evaluation.
+
     Returns:
         The return value of `evaluator.evaluate()`
     """
     num_devices = dist.get_world_size()
     logger = logging.getLogger(__name__)
-    logger.info("Start inference on {} samples".format(len(data_loader)))
 
-    total = len(data_loader)  # inference data loader must have a fixed length
+    total_samples = len(data_loader.dataset)  # inference data loader must have a fixed length
     if evaluator is None:
         # create a no-op evaluator
         evaluator = DatasetEvaluators([])
@@ -142,16 +151,33 @@ def inference_on_dataset(
         evaluator = DatasetEvaluators(evaluator)
     evaluator.reset()
 
-    num_warmup = min(5, total - 1)
+    num_warmup = min(5, len(data_loader) - 1)
     start_time = time.perf_counter()
     total_data_time = 0
     total_compute_time = 0
     total_eval_time = 0
     consumed_samples = 0
-    with flow.no_grad():
+    dps = dist.get_data_parallel_size()
+    last_batch_lack = (dps - (total_samples % dps)) % dps
+
+    # reset total samples
+    real_eval_iter = min(eval_iter, len(data_loader))
+    total_samples = min(real_eval_iter * batch_size, len(data_loader.dataset))
+    logger.info(
+        f"with eval_iter {eval_iter}, "
+        f"reset total samples {len(data_loader.dataset)} to {total_samples}"
+    )
+    logger.info(f"Start inference on {total_samples} samples")
+
+    with ExitStack() as stack:
+        if isinstance(model, (flow.nn.Module, flow.nn.Graph)):
+            stack.enter_context(inference_context(model))
+        stack.enter_context(flow.no_grad())
 
         start_data_time = time.perf_counter()
         for idx, inputs in enumerate(data_loader):
+            if idx >= real_eval_iter:
+                break
             total_data_time += time.perf_counter() - start_data_time
             if idx == num_warmup:
                 start_time = time.perf_counter()
@@ -162,22 +188,33 @@ def inference_on_dataset(
             start_compute_time = time.perf_counter()
             # model forward
             data = get_batch(inputs)
-            paded_data, valid_sample = pad_batch(data, batch_size)
-            outputs = model(*paded_data)
-            valid_data = [d[:valid_sample] for d in data]
-            if isinstance(outputs, (list, tuple)):
-                valid_outputs = [op[:valid_sample] for op in outputs]
-            elif isinstance(outputs, flow.Tensor):
-                valid_outputs = [outputs[:valid_sample]]
-            else:
-                raise NotImplementedError(f"model output type {type(outputs)} is not supported")
+            is_last_batch = idx == len(data_loader) - 1
+            paded_data, valid_sample = pad_batch(data, batch_size, last_batch_lack, is_last_batch)
+            outputs = model(**paded_data)
+
+            # get valid sample
+            valid_data = {
+                key: dist.ttol(value, ranks=[0] if value.placement.ranks.ndim == 1 else [[0]])[
+                    :valid_sample
+                ]
+                for key, value in data.items()
+            }
+            valid_outputs = {}
+            for key, value in outputs.items():
+                value = dist.ttol(value, ranks=[0] if value.placement.ranks.ndim == 1 else [[0]])
+                if value.ndim > 1:
+                    valid_outputs[key] = value[:valid_sample]  # Slice if it's batched output
+                else:
+                    valid_outputs[key] = value
 
             if flow.cuda.is_available():
                 dist.synchronize()
             total_compute_time += time.perf_counter() - start_compute_time
 
             start_eval_time = time.perf_counter()
-            evaluator.process(valid_data, valid_outputs)
+            if dist.is_main_process():
+                evaluator.process(valid_data, valid_outputs)
+            dist.synchronize()
             total_eval_time += time.perf_counter() - start_eval_time
 
             consumed_samples += valid_sample
@@ -188,12 +225,12 @@ def inference_on_dataset(
             total_seconds_per_iter = (time.perf_counter() - start_time) / iters_after_start
             if idx >= num_warmup * 2 or compute_seconds_per_iter > 5:
                 eta = datetime.timedelta(
-                    seconds=int(total_seconds_per_iter * (total // batch_size - idx - 1))
+                    seconds=int(total_seconds_per_iter * (total_samples // batch_size - idx - 1))
                 )
                 log_every_n_seconds(
                     logging.INFO,
                     (
-                        f"Inference done {consumed_samples}/{total}. "
+                        f"Inference done {consumed_samples}/{total_samples}. "
                         f"Dataloading: {data_seconds_per_iter:.4f} s/iter. "
                         f"Inference: {compute_seconds_per_iter:.4f} s/iter. "
                         f"Eval: {eval_seconds_per_iter:.4f} s/iter. "
@@ -208,15 +245,18 @@ def inference_on_dataset(
     total_time = time.perf_counter() - start_time
     total_time_str = str(datetime.timedelta(seconds=total_time))
     # NOTE this format is parsed by grep
+    logger.info("Total valid samples: {}".format(consumed_samples))
     logger.info(
         "Total inference time: {} ({:.6f} s / iter per device, on {} devices)".format(
-            total_time_str, total_time / (total - num_warmup), num_devices
+            total_time_str, total_time / (total_samples - num_warmup), num_devices
         )
     )
     total_compute_time_str = str(datetime.timedelta(seconds=int(total_compute_time)))
     logger.info(
         "Total inference pure compute time: {} ({:.6f} s / iter per device, on {} devices)".format(
-            total_compute_time_str, total_compute_time / (total - num_warmup), num_devices,
+            total_compute_time_str,
+            total_compute_time / (total_samples - num_warmup),
+            num_devices,
         )
     )
 
@@ -226,3 +266,23 @@ def inference_on_dataset(
     if results is None:
         results = {}
     return results
+
+
+@contextmanager
+def inference_context(model):
+    """
+    A context where the model is temporarily changed to eval mode,
+    and restored to previous mode afterwards.
+    Args:
+        model: eager or graph mode in oneflow
+    """
+    training_mode = model.model.training if isinstance(model, flow.nn.Graph) else model.training
+    if isinstance(model, flow.nn.Graph):
+        model.model.eval()
+    else:
+        model.eval()
+    yield
+    if isinstance(model, flow.nn.Graph):
+        model.model.train(training_mode)
+    else:
+        model.train(training_mode)
