@@ -13,13 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .bert_model import BertForPreTraining, BertForPretrainingGraph, BertModel
+from .bert_model import BertForPreTraining, BertModel
 from .build import build_graph, build_model
+from .t5_model import T5ForPreTraining, T5Model
+from .gpt_model import GPTForPreTraining, GPTModel
+from .vision_transformer import VisionTransformer
+from .swin_transformer import SwinTransformer
 
 __all__ = [
     "build_model",
     "build_graph",
     "BertModel",
     "BertForPreTraining",
-    "BertForPretrainingGraph",
+    "T5Model",
+    "T5ForPreTraining",
+    "GPTModel",
+    "GPTForPreTraining",
+    "VisionTransformer",
+    "SwinTransformer",
 ]
